@@ -1,9 +1,9 @@
 package Huawei::Healthchecker;
 
 #版本信息
-our $VERSION = "0.07";
+our $VERSION = "0.09";
 
-use strict;
+use 5.012;
 use warnings;
 use Net::Compare;
 
@@ -332,33 +332,33 @@ sub module_status {
     $result->{"origin"} = $origin;
 
     #快速检查是否有未注册的模块
-    my $ret = ( grep {/Unregistered/} @{$rev} ) ? 1 : 0;
+    my $ret = ( grep {/Unregistered/i} @{$rev} ) ? 1 : 0;
 
     #设备健康检查
     return $result unless $ret;
 
+    my @msg;
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
-        if (/(?<alarm>Unregistered)/) {
+        if (/Unregistered/i) {
 
-            #将巡检结果命令行分割为字符串数组
-            my @info = split( /\s+/, $_ );
-
-            #母板默认显示为-
-            $info[1] = "main_board" if $info[1] eq '-';
-
-            #写入异常状态
-            my $alarm = lc( $+{alarm} );
-            $result->{"log"}
-                = "设备板卡告警： " . $info[1] . " 未加载";
-            $result->{"alarm"} = "critic";
-
-            #监控检查状态
-            $result->{"health"} = "fail";
-            last;
+            #将巡检结果命令行写入数组中
+            push @msg, $_;
         }
     }
 
+    if (@msg) {
+
+        #将异常信息写入日志中
+        $result->{"log"} = "设备板卡告警： \n" . join("\n", @msg);
+        
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #监控检查状态
+        $result->{"health"} = "fail";
+    }
+
     #返回巡检结果
     return $result;
 }
@@ -392,25 +392,27 @@ sub power_status {
     #设备健康检查
     return $result unless $ret;
 
+    my @msg;
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
-        if (/(?<alarm>NotSupply)/i) {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = split( /\s+/, $_ );
-
-            #写入异常状态
-            my $alarm = lc( $+{alarm} );
-            $result->{"log"}
-                = "电源模块告警： " . $info[1] . " 未供电";
-            $result->{"alarm"} = "critic";
-
-            #监控检查状态
-            $result->{"health"} = "fail";
-            last;
+        if (/NotSupply/i) {
+            #将巡检结果命令行写入数组中
+            push @msg, $_;
         }
     }
 
+    if (@msg) {
+
+        #将异常信息写入日志中
+        $result->{"log"} = "设备电源告警： \n" . join("\n", @msg);
+        
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #监控检查状态
+        $result->{"health"} = "fail";
+    }
+
     #返回巡检结果
     return $result;
 }
@@ -444,25 +446,27 @@ sub fan_status {
     #设备健康检查
     return $result unless $ret;
 
+    my @msg;
     #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
-        if (/(?<alarm>Abnormal)/i) {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = split( /\s+/, $_ );
-
-            #写入异常状态
-            my $alarm = lc( $+{alarm} );
-            $result->{"log"}
-                = "设备风扇： " . $info[1] . " 未正常工作";
-            $result->{"alarm"} = "alert";
-
-            #监控检查状态
-            $result->{"health"} = "fail";
-            last;
+        if (/Abnormal/i) {
+            #将巡检结果命令行写入数组中
+            push @msg, $_;
         }
     }
 
+    if (@msg) {
+
+        #将异常信息写入日志中
+        $result->{"log"} = "设备风扇告警： \n" . join("\n", @msg);
+        
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #监控检查状态
+        $result->{"health"} = "fail";
+    }
+
     #返回巡检结果
     return $result;
 }
@@ -496,24 +500,27 @@ sub alarm_status {
     #设备健康检查
     return $result unless $ret;
 
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    my @msg;
+    #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
         if (/(?<alarm>(critic|alert))/i) {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = split( /\s+/, $_ );
-
-            #写入异常状态
-            my $alarm = lc( $+{alarm} );
-            $result->{"alarm"} = $+{alarm};
-            $result->{"log"}   = $_;
-
-            #监控检查状态
-            $result->{"health"} = "fail";
-            last;
+            #将巡检结果命令行写入数组中
+            push @msg, $_;
         }
     }
 
+    if (@msg) {
+
+        #将异常信息写入日志中
+        $result->{"log"} = "设备硬件告警： \n" . join("\n", @msg);
+        
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #监控检查状态
+        $result->{"health"} = "fail";
+    }
+
     #返回巡检结果
     return $result;
 }
@@ -542,29 +549,31 @@ sub temperature_status {
     $result->{"origin"} = $origin;
 
     #快速检查是否有未注册的模块
-    my $ret = ( grep {/(Abnormal)/i} @{$rev} ) ? 1 : 0;
+    my $ret = ( grep {/Abnormal/i} @{$rev} ) ? 1 : 0;
 
     #设备健康检查
     return $result unless $ret;
 
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    my @msg;
+    #遍历巡检结果以捕捉异常模块信息
     foreach ( @{$rev} ) {
-        if (/(?<alarm>(Abnormal))/i) {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = split( /\s+/, $_ );
-
-            #写入异常状态
-            my $alarm = lc( $+{alarm} );
-            $result->{"log"}   = "设备温度告警：" . "->$info[6]";
-            $result->{"alarm"} = "info";
-
-            #监控检查状态
-            $result->{"health"} = "fail";
-            last;
+        if (/Abnormal/i) {
+            #将巡检结果命令行写入数组中
+            push @msg, $_;
         }
     }
 
+    if (@msg) {
+        #将异常信息写入日志中
+        $result->{"log"} = "设备温度告警： \n" . join("\n", @msg);
+        
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #监控检查状态
+        $result->{"health"} = "fail";
+    }
+
     #返回巡检结果
     return $result;
 }
@@ -596,7 +605,7 @@ sub disk_status {
     my $status = 0;
     my $storage;
 
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
 
         #如果命中磁盘关键字将状态指为1
@@ -661,9 +670,7 @@ sub cpu_status {
     my $origin = join( "\n", @{$rev} );
     $result->{"origin"} = $origin;
 
-    #设置缺省检查结果为PASS
-
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
         if (/CPU Using Percentage/i) {
 
@@ -873,36 +880,31 @@ sub vrrp_status {
     $result->{"origin"} = $origin;
 
     #快速检查是否有未注册的模块
-    my $ret = ( grep {/Info(.*?)exist/i} @{$rev} ) ? 1 : 0;
+    my $ret = ( grep {/Info: The VRRP does not exist/i} @{$rev} ) ? 1 : 0;
 
     #巡检结果命令行输出不存在则跳过
     return $result if $ret;
 
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    my @msg;
+    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
         if (/Initialize/i) {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = map {s/(^\s+|\s+$)//r} split( /\:/, $_ );
-
-            #取出内存利用率
-            my $status = $info[1];
-
-            #处理利用率指标前后空白字符串
-            $status =~ s/(^\s+|\s+$)//;
-
-            #写入异常状态
-            $result->{"info"} = "VRRP处于Initialize状态"
-                if ( $status =~ /not/i );
-
-            #设置告警等级
-            $result->{"alarm"} = "critic";
-
-            #监控检查状态
-            $result->{"health"} = "fail";
+            push @msg, $_;
         }
     }
 
+    #写入异常状态信息
+    if (@msg) {
+        #添加异常信息到日志
+        $result->{"log"} = "检测到VRRP工作异常： " . join("\n",@msg);
+
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #写入后续巡检结果
+        $result->{"health"} = "fail";
+    }
+ 
     #返回巡检结果
     return $result;
 }
@@ -931,36 +933,33 @@ sub eth_trunk_status {
     $result->{"origin"} = $origin;
 
     #快速检查是否有未注册的模块
-    my $ret = ( grep {/Info(.*?)exist/i} @{$rev} ) ? 1 : 0;
+    my $ret = ( grep {/Unselect/i} @{$rev} ) ? 1 : 0;
 
     #巡检结果命令行输出不存在则跳过
-    return $result if $ret;
+    return $result unless $ret;
 
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    my @msg;
+    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
+        #匹配异常状态信息
         if (/Unselect/i) {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = map {s/(^\s+|\s+$)//r} split( /\:/, $_ );
-
-            #取出内存利用率
-            my $status = $info[1];
-
-            #处理利用率指标前后空白字符串
-            $status =~ s/(^\s+|\s+$)//;
-
-            #写入异常状态
-            $result->{"log"} = "eth-trunk 部分接口工作异常"
-                if ( $status =~ /not/i );
-
-            #设置告警等级
-            $result->{"alarm"} = "critic";
-
-            #监控检查状态
-            $result->{"health"} = "fail";
+            #将巡检结果命令行写入数组中
+            push @msg, $_;
         }
     }
 
+    if (@msg) {
+
+        #写入异常状态信息
+        $result->{"log"} = "ETH-TRUNK接口异常： " . join("\n",@msg);
+
+        #设置告警等级
+        $result->{"alarm"} = "critic";
+
+        #写入后续巡检结果
+        $result->{"health"} = "fail";
+    }
+
     #返回巡检结果
     return $result;
 }
@@ -989,37 +988,29 @@ sub err_down_status {
     $result->{"origin"} = $origin;
 
     #快速检查是否有未注册的模块
-    my $ret = ( grep {/Info(.*?)exist/i} @{$rev} ) ? 1 : 0;
+    my $ret = ( grep {/Info: No error-down interface exists/i} @{$rev} ) ? 1 : 0;
 
     #巡检结果命令行输出不存在则跳过
     return $result if $ret;
 
- #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
+    my @msg;
+    #遍历巡检结果以捕捉异常模块信息,仅关注最新的告警信息
     foreach ( @{$rev} ) {
-        if (/(?<err_down>(efm-threshold-event|efm-remote-failure|bpdu-protection|link-flap|storm-control|port-security|mac-address-flapping|transceiver-power-low|data-integrity-error|runts-error-statistics|auto-defend))/i
-            )
-        {
-
-            #将巡检结果命令行分割为字符串数组
-            my @info = map {s/(^\s+|\s+$)//r} split( /\:/, $_ );
-
-            #取出内存利用率
-            my $status = $info[1];
-
-            #处理利用率指标前后空白字符串
-            $status =~ s/(^\s+|\s+$)//;
+        if (/(efm-threshold-event|efm-remote-failure|bpdu-protection|link-flap|storm-control|mac-address-flapping)/i) {
+            #将命中行写入数组中
+            push @msg = $_;
+        }
+    }
+    if (@msg) {
 
             #写入异常状态
-            $result->{"log"}
-                = "部分接口处于 error-down " . "$+{err_down}"
-                if ( $status =~ /not/i );
+            $result->{"log"}= "接口 error-down： " . join("\n", @msg);
 
             #设置告警等级
             $result->{"alarm"} = "alert";
 
             #监控检查状态
             $result->{"health"} = "fail";
-        }
     }
 
     #返回巡检结果
